@@ -262,6 +262,11 @@ def test_serialize_to_dict():
     s_dict = Squid.to_dict(s, use_integers_for_enums=False)
     assert s_dict["chromatophores"][0]["color"] == "RED"
 
+    s_new_2 = Squid(mass_kg=20)
+    s_dict_2 = Squid.to_dict(s_new_2, including_default_value_fields=False)
+    expected_dict = {"mass_kg": 20}
+    assert s_dict_2 == expected_dict
+
     new_s = Squid(s_dict)
     assert new_s == s
 
